@@ -26,7 +26,7 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E\N{U+060c} d/\N{U+200f}M",
+    MEd => "E\N{U+060c} d\N{U+200f}/M",
     MMM => "LLL",
     MMMEd => "E\N{U+060c} d MMM",
     MMMMEd => "E\N{U+060c} d MMMM",
@@ -39,7 +39,7 @@
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd\N{U+200f}/MM",
-    Md => "d/\N{U+200f}M",
+    Md => "d\N{U+200f}/M",
     d => "d",
     h => "h a",
     hm => "h:mm a",
@@ -49,7 +49,7 @@
     ms => "mm:ss",
     y => "y",
     yM => "M\N{U+200f}/y",
-    yMEd => "E\N{U+060c} d/\N{U+200f}M/\N{U+200f}y",
+    yMEd => "E\N{U+060c} d\N{U+200f}/M\N{U+200f}/y",
     yMM => "MM\N{U+200f}/y",
     yMMM => "MMM y",
     yMMMEd => "E\N{U+060c} d MMM y",
@@ -70,10 +70,10 @@
   date_format_long => "d MMMM y",
   date_format_medium => "dd\N{U+200f}/MM\N{U+200f}/y",
   date_format_short => "d\N{U+200f}/M\N{U+200f}/y",
-  datetime_format_full => "{1} \N{U+0641}\N{U+064a} {0}",
-  datetime_format_long => "{1} \N{U+0641}\N{U+064a} {0}",
-  datetime_format_medium => "{1}, {0}",
-  datetime_format_short => "{1}, {0}",
+  datetime_format_full => "{1}\N{U+060c} {0}",
+  datetime_format_long => "{1}\N{U+060c} {0}",
+  datetime_format_medium => "{1}\N{U+060c} {0}",
+  datetime_format_short => "{1}\N{U+060c} {0}",
   day_format_abbreviated => [
     "\N{U+0627}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0646}\N{U+064a}\N{U+0646}",
     "\N{U+0627}\N{U+0644}\N{U+062b}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0627}\N{U+0621}",
@@ -280,5 +280,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 41,
+  version => 43,
 }
