@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -136,7 +137,7 @@
   glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%H:%M:%S",
-  language => "Fulah",
+  language => "Fula",
   month_format_abbreviated => [
     "sii",
     "col",
@@ -221,10 +222,10 @@
     "jolal",
     "bowte",
   ],
-  name => "Fulah Liberia Latin",
+  name => "Fula Liberia Latin",
   native_language => "Pulaar",
-  native_name => "Pulaar Liberiyaa Latn",
-  native_script => "Latn",
+  native_name => "Pulaar Liberiyaa",
+  native_script => undef,
   native_territory => "Liberiyaa",
   native_variant => undef,
   quarter_format_abbreviated => [
@@ -265,10 +266,10 @@
   ],
   script => "Latin",
   territory => "Liberia",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 37,
+  version => 43,
 }
