@@ -13,12 +13,12 @@
     EHm => "E. HH:mm",
     EHms => "E. HH:mm:ss",
     Ed => "dd. E",
-    Ehm => "E. h:mm a",
-    Ehms => "E. h:mm:ss a",
+    Ehm => "E. h:mm\N{U+202f}a",
+    Ehms => "E. h:mm:ss\N{U+202f}a",
     Gy => "G y",
-    GyMMM => "G y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM",
-    GyMMMEd => "G y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d. E",
-    GyMMMd => "G y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
+    GyMMM => "G y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM",
+    GyMMMEd => "G y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d. E",
+    GyMMMd => "G y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
     GyMd => "GGGGG y-MM-dd",
     H => "HH '\N{U+0446}'",
     Hm => "HH:mm",
@@ -36,28 +36,28 @@
     Md => "MMMMM/dd",
     d => "d",
     h => "h '\N{U+0446}' a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a (v)",
-    hmv => "h:mm a (v)",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a (v)",
+    hmv => "h:mm\N{U+202f}a (v)",
     ms => "mm:ss",
     y => "y",
     yM => "y MMMMM",
     yMEd => "y.MM.dd. E",
-    yMMM => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM",
-    yMMMEd => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d. E",
-    yMMMM => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMMM",
-    yMMMd => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
+    yMMM => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM",
+    yMMMEd => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d. E",
+    yMMMM => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMMM",
+    yMMMd => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
     yMd => "y.MM.dd",
-    yQQQ => "y '\N{U+043e}\N{U+043d}\N{U+044b}' QQQ",
-    yQQQQ => "y '\N{U+043e}\N{U+043d}\N{U+044b}' QQQQ",
+    yQQQ => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' QQQ",
+    yQQQQ => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' QQQQ",
     "yw-count-one" => "Y '\N{U+043e}\N{U+043d}\N{U+044b}' w-'\N{U+0440}' '\N{U+0434}\N{U+043e}\N{U+043b}\N{U+043e}\N{U+043e}' '\N{U+0445}\N{U+043e}\N{U+043d}\N{U+043e}\N{U+0433}'",
     "yw-count-other" => "Y '\N{U+043e}\N{U+043d}\N{U+044b}' w-'\N{U+0440}' '\N{U+0434}\N{U+043e}\N{U+043b}\N{U+043e}\N{U+043e}' '\N{U+0445}\N{U+043e}\N{U+043d}\N{U+043e}\N{U+0433}'",
   },
   code => "mn-MN",
-  date_format_full => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMMM'\N{U+044b}\N{U+043d}' d, EEEE '\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0430}\N{U+0433}'",
-  date_format_long => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMMM'\N{U+044b}\N{U+043d}' d",
-  date_format_medium => "y '\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
+  date_format_full => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMMM'\N{U+044b}\N{U+043d}' d, EEEE '\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0430}\N{U+0433}'",
+  date_format_long => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMMM'\N{U+044b}\N{U+043d}' d",
+  date_format_medium => "y\N{U+202f}'\N{U+043e}\N{U+043d}\N{U+044b}' MMM'\N{U+044b}\N{U+043d}' d",
   date_format_short => "y.MM.dd",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
@@ -269,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 43,
 }
