@@ -59,8 +59,8 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "dd-MM-y",
-  datetime_format_full => "{1} 'om' {0}",
-  datetime_format_long => "{1} 'om' {0}",
+  datetime_format_full => "{1} {0}",
+  datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
@@ -137,18 +137,18 @@
   glibc_time_format => "%H:%M:%S",
   language => "Dutch",
   month_format_abbreviated => [
-    "jan.",
-    "feb.",
-    "mrt.",
-    "apr.",
+    "jan",
+    "feb",
+    "mrt",
+    "apr",
     "mei",
-    "jun.",
-    "jul.",
-    "aug.",
-    "sep.",
-    "okt.",
-    "nov.",
-    "dec.",
+    "jun",
+    "jul",
+    "aug",
+    "sep",
+    "okt",
+    "nov",
+    "dec",
   ],
   month_format_narrow => [
     "J",
@@ -179,18 +179,18 @@
     "december",
   ],
   month_stand_alone_abbreviated => [
-    "jan.",
-    "feb.",
-    "mrt.",
-    "apr.",
+    "jan",
+    "feb",
+    "mrt",
+    "apr",
     "mei",
-    "jun.",
-    "jul.",
-    "aug.",
-    "sep.",
-    "okt.",
-    "nov.",
-    "dec.",
+    "jun",
+    "jul",
+    "aug",
+    "sep",
+    "okt",
+    "nov",
+    "dec",
   ],
   month_stand_alone_narrow => [
     "J",
@@ -269,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 43,
 }
