@@ -34,9 +34,9 @@
     MMMd => "d MMM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
@@ -53,9 +53,9 @@
     "yw-count-other" => "'week' w 'of' Y",
   },
   code => "os",
-  date_format_full => "EEEE, d MMMM, y '\N{U+0430}\N{U+0437}'",
-  date_format_long => "d MMMM, y '\N{U+0430}\N{U+0437}'",
-  date_format_medium => "dd MMM y '\N{U+0430}\N{U+0437}'",
+  date_format_full => "EEEE, d MMMM, y\N{U+202f}'\N{U+0430}\N{U+0437}'",
+  date_format_long => "d MMMM, y\N{U+202f}'\N{U+0430}\N{U+0437}'",
+  date_format_medium => "dd MMM y\N{U+202f}'\N{U+0430}\N{U+0437}'",
   date_format_short => "dd.MM.yy",
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 43,
 }
