@@ -13,8 +13,8 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d E",
-    Ehm => "E a h:mm",
-    Ehms => "E a h:mm:ss",
+    Ehm => "E a\N{U+202f}h:mm",
+    Ehms => "E a\N{U+202f}h:mm:ss",
     Gy => "G y",
     GyMMM => "G MMM y",
     GyMMMEd => "G d MMM y E",
@@ -36,11 +36,11 @@
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "a h",
-    hm => "a h:mm",
-    hms => "a h:mm:ss",
-    hmsv => "a h:mm:ss v",
-    hmv => "a h:mm v",
+    h => "a\N{U+202f}h",
+    hm => "a\N{U+202f}h:mm",
+    hms => "a\N{U+202f}h:mm:ss",
+    hmsv => "a\N{U+202f}h:mm:ss v",
+    hmv => "a\N{U+202f}h:mm v",
     mmss => "mm:ss",
     ms => "mm:ss",
     y => "y",
@@ -267,10 +267,10 @@
   ],
   script => undef,
   territory => "Cyprus",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 41,
+  version => 43,
 }
