@@ -13,8 +13,8 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E, d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "G y",
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
@@ -35,11 +35,11 @@
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
@@ -256,10 +256,10 @@
     "K\N{U+025b}r",
   ],
   quarter_stand_alone_wide => [
-    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
-    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
+    "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
+    "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin Kej\N{U+00ec}",
     "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin K\N{U+025b}ta",
-    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
+    "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin K\N{U+025b}rin",
   ],
   script => undef,
   territory => "Benin",
@@ -268,5 +268,5 @@
   time_format_medium => "H:m:s",
   time_format_short => "H:m",
   variant => undef,
-  version => 41,
+  version => 43,
 }
